import grtoolkit.Circuits
import grtoolkit.Decorators
import grtoolkit.Economics
import grtoolkit.File
import grtoolkit.Format
import grtoolkit.Hardcode
import grtoolkit.Heat
import grtoolkit.Math
import grtoolkit.Mechanics
import grtoolkit.MSAccess
import grtoolkit.PDF
import grtoolkit.Python
import grtoolkit.Quotes
import grtoolkit.Storage
import grtoolkit.TTS
import grtoolkit.Windows

#### EASY ACCESSS FUNCTIONS

import os, sys
def cwd():
    return os.path.dirname(sys.argv[0])