
def collisionsRefresh():
    text = """
    3 different kinds of collisions. In all situations conservation of momentum is conserved.

    Perfectly elastic: All kinetic energy is conserved. Two colliding bodies perfectly exchange 
                       velocities.

    Inelastic: Some kinetic energy is conserved while some is lost to heat or sound.

    Completely inelastic: Colliding bodies have share a common final velocity with both mass 
                          moving in the same direction.
                          Example: two polar opposite magnets of the same mass collide and travel 
                                   in the direction of the net velocity at half the speed due to 
                                   their combined mass.
    """
    print(text)